"""
Mean Qsca vs Diameter
=====================

.. image:: ../../images/Examples/Example18.png
   :width: 600
   :align: center
"""

# sphinx_gallery_thumbnail_path = '../images/Examples/Example18.png'


def run():
    import numpy as np
    from PyMieSim.Experiment import SphereSet, SourceSet, Setup
    from PyMieSim.Materials  import FusedSilica
    from PyMieSim            import Measure, Variables

    Diameter     = np.geomspace(6.36e-09, 10000e-9, 1500)
    Wavelength   = [500e-9, 1000e-9, 1500e-9]

    scatSet = SphereSet(Diameter = Diameter,
                        Material = FusedSilica,
                        nMedium  = 1 )

    sourceSet = SourceSet(Wavelength   = Wavelength,
                          Polarization = 30,
                          Amplitude    = 1)

    Experiment = Setup(ScattererSet = scatSet, SourceSet = sourceSet)

    Data = Experiment.Get(Measure.Qsca)

    Data.Plot(y=Measure.Qsca, x=Variables.Diameter).Show()

if __name__ == '__main__':
    run()
