from DataVisual import XParameter
from PyMieSim.Tools.utils import ToList
from PyOptik import ExpData


__all__ = ['CoreDiameter' ,
           'ShellDiameter',
           'Diameter'     ,
           'CoreIndex'    ,
           'ShellIndex'   ,
           'Index'        ,
           'CoreMaterial' ,
           'ShellMaterial',
           'Material'     ,
           'nMedium'      ,
           'Wavelength'   ,
           'Polarization' ,
           'Amplitude'    ,
           'CField'       ,
           'NA'           ,
           'PhiOffset'    ,
           'GammaOffset'  ,
           'Filter'       ]

CoreDiameter  = XParameter(Name='CoreDiameter',  Format=".1e", Unit="m",      LongLabel='Core diameter',  Legend='C. diameter', Type=float)
ShellDiameter = XParameter(Name='ShellDiameter', Format=".1e", Unit="m",      LongLabel='Shell diameter', Legend='S. diameter', Type=float)
Diameter      = XParameter(Name='Diameter',      Format=".2e", Unit="m",      LongLabel='Diameter',       Legend='Diameter',    Type=float)

CoreIndex     = XParameter(Name='CoreIndex',     Format=".2f", Unit="1",      LongLabel='Core Index',     Legend='C. index',    Type=complex)
ShellIndex    = XParameter(Name='ShellIndex',    Format=".2f", Unit="1",      LongLabel='Shell Index',    Legend='S. index',    Type=complex)
Index         = XParameter(Name='Index',         Format=".2f", Unit="1",      LongLabel='Index',          Legend='Index',       Type=complex)

CoreMaterial  = XParameter(Name='CoreMaterial',  Format="",    Unit="",         LongLabel='Core material',  Legend='C. material', Type=ExpData)
ShellMaterial = XParameter(Name='ShellMaterial', Format="",    Unit="",         LongLabel='Shell material', Legend='S. material', Type=ExpData)
Material      = XParameter(Name='Material',      Format="",    Unit="",         LongLabel='Material',       Legend='Material',    Type=ExpData)

nMedium       = XParameter(Name='nMedium',      LongLabel = 'nMedium',          Format=".2f", Unit="1",     Legend='nMedium', Type=float)
Wavelength    = XParameter(Name='Wavelength',   LongLabel = 'Wavelength',       Format=".1e", Unit="m",     Legend='Wavelength', Type=float)
Polarization  = XParameter(Name='Polarization', LongLabel = 'Polarization',     Format=".1f", Unit="Deg",   Legend='Polarization', Type=float)
Amplitude     = XParameter(Name='Amplitude',    LongLabel = 'Amplitude',        Format=".1e", Unit="w.m⁻¹", Legend='Amplitude', Type=float)


CField        = XParameter(Name='Field',        LongLabel='Coupling field',     Format=None,    Unit="",     Legend='C.F',          Type=tuple)
NA            = XParameter(Name='NA',           LongLabel='Numerical aperture', Format=".3f",   Unit="Rad",  Legend='NA',           Type=float)
PhiOffset     = XParameter(Name='PhiOffset',    LongLabel='Phi offset',         Format="03.1f", Unit="Deg",  Legend='Phi offset',   Type=float)
GammaOffset   = XParameter(Name='GammaOffset',  LongLabel='Gamma offset',       Format="03.1f", Unit="Deg",  Legend='Gamma offset', Type=float)
Filter        = XParameter(Name='Filter',       LongLabel='Filter',             Format="03.1f", Unit="Deg",  Legend='Filter angle', Type=float)


Local = locals()
adict = {e : Local[e] for e in __all__}

def GetKwargs(**kwargs):

    Output = {k:adict[k] for k in kwargs.keys() if k in adict}

    for key, element in Output.items():
        element.Values = ToList(kwargs[key]).astype(element.Type)

    return Output
